@@ -147,7 +147,7 @@ pub const DEFAULT_MANIFEST: &str = r##"
 name = "#{name}"
 version = "0.1.0"
 authors = ["Anonymous"]
-edition = "2018"
+edition = "2021"
 
 [[bin]]
 name = "#{bin_name}"
@@ -159,7 +159,7 @@ pub const DEFAULT_MANIFEST: &str = r##"
 name = "#{name}"
 version = "0.1.0"
 authors = ["Anonymous"]
-edition = "2018"
+edition = "2021"
 
 [[bin]]
 name = "#{bin_name}"
@@ -169,16 +169,6 @@ path = "#{file}.rs"
 strip = true
 "##;
 
-/**
-The name of the package metadata file.
-*/
-pub const METADATA_FILE: &str = "metadata.json";
-
-/**
-Extensions to check when trying to find script input by name.
-*/
-pub const SEARCH_EXTS: &[&str] = &["ers", "rs"];
-
 /**
 When generating a package's unique ID, how many hex nibbles of the digest should be used *at most*?
 
