@@ -18,6 +18,9 @@ mod file_assoc;
 #[cfg(not(windows))]
 mod file_assoc {}
 
+#[cfg(unix)]
+use std::os::unix::process::CommandExt;
+
 use log::{debug, error, info};
 use serde::{Deserialize, Serialize};
 use std::ffi::OsString;
@@ -92,7 +95,6 @@ impl BuildKind {
 
 fn parse_args() -> Args {
     use clap::{Arg, ArgGroup, Command};
-    use std::iter::FromIterator;
     let version = option_env!("CARGO_PKG_VERSION").unwrap_or("unknown");
     let about = r#"Compiles and runs a Rust script."#;
 
@@ -268,7 +270,7 @@ fn parse_args() -> Args {
     let script;
     let script_args: Vec<String>;
     if let Some(script_and_args) = script_and_args {
-        script = script_and_args.get(0).map(|s| s.to_string());
+        script = script_and_args.first().map(|s| s.to_string());
         script_args = if script_and_args.len() > 1 {
             Vec::from_iter(script_and_args[1..].iter().map(|s| s.to_string()))
         } else {
@@ -311,14 +313,12 @@ fn parse_args() -> Args {
 fn main() {
     env_logger::init();
 
-    let stderr = &mut std::io::stderr();
     match try_main() {
-        Ok(0) => (),
         Ok(code) => {
             std::process::exit(code);
         }
-        Err(ref err) => {
-            writeln!(stderr, "error: {}", err).unwrap();
+        Err(err) => {
+            eprintln!("error: {}", err);
             std::process::exit(1);
         }
     }
@@ -352,7 +352,8 @@ fn try_main() -> MainResult<i32> {
         return Ok(0);
     }
 
-    // Take the arguments and work out what our input is going to be.  Primarily, this gives us the content, a user-friendly name, and a cache-friendly ID.
+    // Take the arguments and work out what our input is going to be.
+    // Primarily, this gives us the content, a user-friendly name, and a cache-friendly ID.
     // These three are just storage for the borrows we'll actually use.
     let script_name: String;
     let script_path: PathBuf;
@@ -370,11 +371,11 @@ fn try_main() -> MainResult<i32> {
 
             let mut body = String::new();
             file.read_to_string(&mut body)?;
+            content = body;
 
             let mtime = platform::file_last_modified(&file);
 
             script_path = std::env::current_dir()?.join(path);
-            content = body;
 
             Input::File(&script_name, &script_path, &content, mtime)
         }
@@ -478,18 +479,30 @@ fn try_main() -> MainResult<i32> {
         })
     };
 
-    let exit_code = if action.execute {
-        let cmd_name = action.build_kind.exec_command();
-        info!("running `cargo {}`", cmd_name);
-        let run_quietly = !action.cargo_output;
-        let mut cmd = action.cargo(cmd_name, &args.script_args, run_quietly)?;
+    #[cfg(unix)]
+    {
+        if action.execute {
+            let run_quietly = !action.cargo_output;
+            let mut cmd = action.cargo(action.build_kind, &args.script_args, run_quietly)?;
 
-        cmd.status().map(|st| st.code().unwrap_or(1))?
-    } else {
-        0
-    };
+            let err = cmd.exec();
+            Err(MainError::from(err))
+        } else {
+            Ok(0)
+        }
+    }
+    #[cfg(not(unix))]
+    {
+        let exit_code = if action.execute {
+            let run_quietly = !action.cargo_output;
+            let mut cmd = action.cargo(action.build_kind, &args.script_args, run_quietly)?;
 
-    Ok(exit_code)
+            cmd.status().map(|st| st.code().unwrap_or(1))?
+        } else {
+            0
+        };
+        Ok(exit_code)
+    }
 }
 
 /**
@@ -698,10 +711,15 @@ impl InputAction {
         self.pkg_path.join("Cargo.toml")
     }
 
-    fn cargo(&self, cmd: &str, script_args: &[String], run_quietly: bool) -> MainResult<Command> {
+    fn cargo(
+        &self,
+        build_kind: BuildKind,
+        script_args: &[String],
+        run_quietly: bool,
+    ) -> MainResult<Command> {
         cargo(
-            cmd,
-            &*self.manifest_path().to_string_lossy(),
+            build_kind,
+            &self.manifest_path().to_string_lossy(),
             self.toolchain_version.as_deref(),
             &self.metadata,
             script_args,
@@ -724,9 +742,6 @@ struct PackageMetadata {
     /// Last-modified timestamp for script file.
     modified: Option<u128>,
 
-    /// Template used.
-    template: Option<String>,
-
     /// Was the script compiled in debug mode?
     debug: bool,
 
@@ -784,17 +799,15 @@ fn decide_action_for(
     };
 
     let input_meta = {
-        let (path, mtime, template) = match *input {
+        let (path, mtime) = match *input {
             Input::File(_, path, _, mtime) => {
-                (Some(path.to_string_lossy().into_owned()), Some(mtime), None)
+                (Some(path.to_string_lossy().into_owned()), Some(mtime))
             }
-            Input::Expr(_, template) => (None, None, template),
-            Input::Loop(..) => (None, None, None),
+            _ => (None, None),
         };
         PackageMetadata {
             path,
             modified: mtime,
-            template: template.map(Into::into),
             debug,
             deps,
             prelude,
@@ -893,7 +906,7 @@ fn get_pkg_metadata_path<P>(pkg_path: P) -> PathBuf
 where
     P: AsRef<Path>,
 {
-    pkg_path.as_ref().join(consts::METADATA_FILE)
+    pkg_path.as_ref().join("metadata.json")
 }
 
 /**
@@ -914,34 +927,26 @@ where
     Ok(())
 }
 
-/**
-Attempts to locate the script specified by the given path.  If the path as-given doesn't yield anything, it will try adding file extensions.
-*/
+/// Attempts to locate the script specified by the given path.
 fn find_script<P>(path: P) -> Option<(PathBuf, fs::File)>
 where
     P: AsRef<Path>,
 {
     let path = path.as_ref();
 
-    // Try the path directly.
     if let Ok(file) = fs::File::open(path) {
         return Some((path.into(), file));
     }
 
-    // If it had an extension, don't bother trying any others.
-    if path.extension().is_some() {
-        return None;
-    }
-
-    // Ok, now try other extensions.
-    for &ext in consts::SEARCH_EXTS {
-        let path = path.with_extension(ext);
-        if let Ok(file) = fs::File::open(&path) {
-            return Some((path, file));
+    if path.extension().is_none() {
+        for &ext in &["ers", "rs"] {
+            let path = path.with_extension(ext);
+            if let Ok(file) = fs::File::open(&path) {
+                return Some((path, file));
+            }
         }
     }
 
-    // Welp. ¯\_(ツ)_/¯
     None
 }
 
@@ -1157,7 +1162,7 @@ where
 Constructs a Cargo command that runs on the script package.
 */
 fn cargo(
-    cmd_name: &str,
+    build_kind: BuildKind,
     manifest: &str,
     maybe_toolchain_version: Option<&str>,
     meta: &PackageMetadata,
@@ -1168,9 +1173,9 @@ fn cargo(
     if let Some(toolchain_version) = maybe_toolchain_version {
         cmd.arg(format!("+{}", toolchain_version));
     }
-    cmd.arg(cmd_name);
+    cmd.arg(build_kind.exec_command());
 
-    if cmd_name == "run" && run_quietly {
+    if matches!(build_kind, BuildKind::Normal) && run_quietly {
         cmd.arg("-q");
     }
 
@@ -1185,7 +1190,7 @@ fn cargo(
     cmd.arg(cargo_target_dir);
 
     // Block `--release` on `bench`.
-    if !meta.debug && cmd_name != "bench" {
+    if !meta.debug && !matches!(build_kind, BuildKind::Bench) {
         cmd.arg("--release");
     }
 
@@ -1193,7 +1198,7 @@ fn cargo(
         cmd.arg("--features").arg(features);
     }
 
-    if cmd_name == "run" && !script_args.is_empty() {
+    if matches!(build_kind, BuildKind::Normal) && !script_args.is_empty() {
         cmd.arg("--");
         cmd.args(script_args.iter());
     }
